@@ -24,9 +24,8 @@
 #ifndef _NAUTILUS_SENDTO_PLUGIN_H_
 #define _NAUTILUS_SENDTO_PLUGIN_H_
 
-#include <gnome.h>
-#include <glib.h>
 #include <gmodule.h>
+#include <gtk/gtk.h>
 
 typedef struct _NstPluginInfo NstPluginInfo;
 typedef struct _NstPlugin NstPlugin;
@@ -39,6 +38,7 @@ struct _NstPluginInfo
 	gboolean never_unload;
 	gboolean (*init)(NstPlugin *plugin);
 	GtkWidget* (*get_contacts_widget)(NstPlugin *plugin);
+	gboolean (*validate_destination)(NstPlugin *plugin, GtkWidget *contact_widget, char **error);
 	gboolean (*send_files)(NstPlugin *plugin, GtkWidget *contact_widget,
 				GList *file_list);
     	gboolean (*destroy)(NstPlugin *plugin) ;
@@ -51,6 +51,7 @@ struct _NstPlugin
 };
 
 # define NST_INIT_PLUGIN(plugininfo) \
+	gboolean nst_init_plugin(NstPlugin *plugin); \
         G_MODULE_EXPORT gboolean nst_init_plugin(NstPlugin *plugin) { \
 		plugin->info = &(plugininfo);\
                 return TRUE;\
